@@ -1,4 +1,5 @@
 import contextlib
+import contextvars
 import dataclasses
 from typing import (
     Any,
@@ -79,7 +80,7 @@ def _get_model_hints(
     # are actually inside edges -> node selection...
     if type_def.concrete_of and issubclass(type_def.concrete_of.origin, Connection):
         n_type = type_def.type_var_map[NodeType]
-        n_type_def = n_type._type_definition  # type:ignore
+        n_type_def = cast(TypeDefinition, n_type._type_definition)  # type:ignore
 
         for edges in get_selections(selection, typename=typename).values():
             if edges.name != "edges":
@@ -113,7 +114,9 @@ def _get_model_hints(
         store.only.append(pk.attname)
 
     for f_selection in get_selections(selection, typename=typename).values():
-        field = fields[f_selection.name]
+        field = fields.get(f_selection.name, None)
+        if not field:
+            continue
 
         # Add annotations from the field if they exist
         field_store = getattr(field, "store", None)
@@ -239,7 +242,7 @@ def optimize(
         qs = cast(QuerySet[_M], qs.all())
 
     # If the queryset already has cached results, just return it
-    if qs._result_cache:  # type:ignore
+    if qs._result_cache is not None:  # type:ignore
         return qs
 
     if isinstance(info, Info):
@@ -424,6 +427,12 @@ class OptimizerStore:
         return qs
 
 
+optimizer: contextvars.ContextVar[Optional["DjangoOptimizerExtension"]] = contextvars.ContextVar(
+    "optimizer_ctx",
+    default=None,
+)
+
+
 class DjangoOptimizerExtension(Extension):
     """Automatically optimize returned querysets from internal resolvers.
 
@@ -461,7 +470,7 @@ class DjangoOptimizerExtension(Extension):
         execution_context: ExecutionContext = None,
     ):
         super().__init__(execution_context=execution_context)  # type:ignore
-        self._config = OptimizerConfig(
+        self.config = OptimizerConfig(
             enable_only=enable_only_optimization,
             enable_select_related=enable_select_related_optimization,
             enable_prefetch_related=enable_prefetch_related_optimization,
@@ -475,10 +484,10 @@ class DjangoOptimizerExtension(Extension):
         cls._disabled = False
 
     def on_request_start(self) -> AwaitableOrValue[None]:
-        if self._disabled:
-            return
+        optimizer.set(self)
 
-        self.execution_context.context._django_optimizer_config = self._config
+    def on_request_end(self) -> AwaitableOrValue[None]:
+        optimizer.set(None)
 
     def resolve(
         self,
@@ -496,7 +505,19 @@ class DjangoOptimizerExtension(Extension):
         if isinstance(ret, (BaseManager, QuerySet)):
             if isinstance(ret, BaseManager):
                 ret = ret.all()
-            if not ret._result_cache:  # type:ignore
-                return resolvers.resolve_qs(optimize(qs=ret, info=info, config=self._config))
+            if ret._result_cache is None:  # type:ignore
+                return resolvers.resolve_qs(optimize(qs=ret, info=info, config=self.config))
 
         return ret
+
+    def optimize(
+        self,
+        qs: Union[QuerySet[_M], BaseManager[_M]],
+        info: Union[GraphQLResolveInfo, Info],
+        *,
+        store: Optional["OptimizerStore"] = None,
+    ) -> QuerySet[_M]:
+        if self._disabled:
+            return qs
+
+        return optimize(qs, info, config=self.config, store=store)
